@@ -88,7 +88,7 @@ sub add {
     my ($self, @pathes) = @_;
     my $command =
           "command_list_begin\n"
-        . join( '', map { qq[add "$_"\n] } @pathes )
+        . join( '', map { s/"/\\"/g; qq[add "$_"\n] } @pathes )
         . "command_list_end\n";
     $self->_mpd->_send_command( $command );
 }
@@ -104,7 +104,7 @@ sub delete {
     my ($self, @songs) = @_;
     my $command =
           "command_list_begin\n"
-        . join( '', map { "delete $_\n" } @songs )
+        . join( '', map { s/"/\\"/g; "delete $_\n" } @songs )
         . "command_list_end\n";
     $self->_mpd->_send_command( $command );
 }
